@@ -3,9 +3,12 @@
  * @brief Header file for the FrameMapper class
  * @author Jonathan Thomas <jonathan@openshot.org>
  *
- * @section LICENSE
+ * @ref License
+ */
+
+/* LICENSE
  *
- * Copyright (c) 2008-2014 OpenShot Studios, LLC
+ * Copyright (c) 2008-2019 OpenShot Studios, LLC
  * <http://www.openshotstudios.com/>. This file is part of
  * OpenShot Library (libopenshot), an open-source project dedicated to
  * delivering high quality video editing and animation solutions to the
@@ -34,11 +37,11 @@
 #include <vector>
 #include <memory>
 #include "CacheMemory.h"
-#include "../include/ReaderBase.h"
-#include "../include/Frame.h"
-#include "../include/Fraction.h"
-#include "../include/Exceptions.h"
-#include "../include/KeyFrame.h"
+#include "ReaderBase.h"
+#include "Frame.h"
+#include "Fraction.h"
+#include "Exceptions.h"
+#include "KeyFrame.h"
 
 
 // Include FFmpeg headers and macros
@@ -46,9 +49,6 @@
 #include "OpenMPUtilities.h"
 
 
-
-using namespace std;
-
 namespace openshot
 {
 	/**
@@ -72,12 +72,12 @@ namespace openshot
 	 */
 	struct Field
 	{
-		long int Frame;
+		int64_t Frame;
 		bool isOdd;
 
 		Field() : Frame(0), isOdd(true) { };
 
-		Field(long int frame, bool isodd)
+		Field(int64_t frame, bool isodd)
 		{
 			Frame = frame;
 			isOdd = isodd;
@@ -92,10 +92,10 @@ namespace openshot
 	 */
 	struct SampleRange
 	{
-		int frame_start;
+		int64_t frame_start;
 		int sample_start;
 
-		int frame_end;
+		int64_t frame_end;
 		int sample_end;
 
 		int total;
@@ -146,15 +146,14 @@ namespace openshot
 		ReaderBase *reader;		// The source video reader
 		CacheMemory final_cache; 		// Cache of actual Frame objects
 		bool is_dirty; 			// When this is true, the next call to GetFrame will re-init the mapping
-		AVAudioResampleContext *avr;	// Audio resampling context object
-		long int timeline_frame_offset;	// Timeline frame offset
+		SWRCONTEXT *avr;	// Audio resampling context object
 
 		// Internal methods used by init
-		void AddField(long int frame);
+		void AddField(int64_t frame);
 		void AddField(Field field);
 
 		// Get Frame or Generate Blank Frame
-		std::shared_ptr<Frame> GetOrCreateFrame(long int number);
+		std::shared_ptr<Frame> GetOrCreateFrame(int64_t number);
 
 		// Use the original and target frame rates and a pull-down technique to create
 		// a mapping between the original fields and frames or a video to a new frame rate.
@@ -164,26 +163,23 @@ namespace openshot
 
 	public:
 		// Init some containers
-		vector<Field> fields;		// List of all fields
-		vector<MappedFrame> frames;	// List of all frames
+		std::vector<Field> fields;		// List of all fields
+		std::vector<MappedFrame> frames;	// List of all frames
 
 		/// Default constructor for openshot::FrameMapper class
 		FrameMapper(ReaderBase *reader, Fraction target_fps, PulldownType target_pulldown, int target_sample_rate, int target_channels, ChannelLayout target_channel_layout);
 
 		/// Destructor
-		~FrameMapper();
+		virtual ~FrameMapper();
 
 		/// Change frame rate or audio mapping details
 		void ChangeMapping(Fraction target_fps, PulldownType pulldown,  int target_sample_rate, int target_channels, ChannelLayout target_channel_layout);
 
-		// Set offset relative to parent timeline
-		void SetTimelineFrameOffset(long int offset);
-
 		/// Close the openshot::FrameMapper and internal reader
 		void Close();
 
 		/// Get a frame based on the target frame rate and the new frame number of a frame
-		MappedFrame GetMappedFrame(long int TargetFrameNumber) throw(OutOfBoundsFrame);
+		MappedFrame GetMappedFrame(int64_t TargetFrameNumber);
 
 		/// Get the cache object used by this reader
 		CacheMemory* GetCache() { return &final_cache; };
@@ -194,31 +190,34 @@ namespace openshot
 		///
 		/// @returns The requested frame of video
 		/// @param requested_frame The frame number that is requested.
-		std::shared_ptr<Frame> GetFrame(long int requested_frame) throw(ReaderClosed);
+		std::shared_ptr<Frame> GetFrame(int64_t requested_frame);
 
 		/// Determine if reader is open or closed
 		bool IsOpen();
 
 		/// Return the type name of the class
-		string Name() { return "FrameMapper"; };
+		std::string Name() { return "FrameMapper"; };
 
 		/// Get and Set JSON methods
-		string Json(); ///< Generate JSON string of this object
-		void SetJson(string value) throw(InvalidJSON); ///< Load JSON string into this object
+		std::string Json(); ///< Generate JSON string of this object
+		void SetJson(std::string value); ///< Load JSON string into this object
 		Json::Value JsonValue(); ///< Generate Json::JsonValue for this object
-		void SetJsonValue(Json::Value root) throw(InvalidFile); ///< Load Json::JsonValue into this object
+		void SetJsonValue(Json::Value root); ///< Load Json::JsonValue into this object
 
 		/// Open the internal reader
-		void Open() throw(InvalidFile);
+		void Open();
 
 		/// Print all of the original frames and which new frames they map to
 		void PrintMapping();
 
 		/// Get the current reader
-		ReaderBase* Reader() throw(ReaderClosed);
+		ReaderBase* Reader();
+
+		/// Set the current reader
+		void Reader(ReaderBase *new_reader) { reader = new_reader; }
 
 		/// Resample audio and map channels (if needed)
-		void ResampleMappedAudio(std::shared_ptr<Frame> frame, long int original_frame_number);
+		void ResampleMappedAudio(std::shared_ptr<Frame> frame, int64_t original_frame_number);
 
 	};
 }
