@@ -3,9 +3,12 @@
  * @brief Header file for ImageReader class
  * @author Jonathan Thomas <jonathan@openshot.org>
  *
- * @section LICENSE
+ * @ref License
+ */
+
+/* LICENSE
  *
- * Copyright (c) 2008-2014 OpenShot Studios, LLC
+ * Copyright (c) 2008-2019 OpenShot Studios, LLC
  * <http://www.openshotstudios.com/>. This file is part of
  * OpenShot Library (libopenshot), an open-source project dedicated to
  * delivering high quality video editing and animation solutions to the
@@ -28,6 +31,9 @@
 #ifndef OPENSHOT_IMAGE_READER_H
 #define OPENSHOT_IMAGE_READER_H
 
+// Require ImageMagick support
+#ifdef USE_IMAGEMAGICK
+
 #include "ReaderBase.h"
 
 #include <cmath>
@@ -35,12 +41,10 @@
 #include <iostream>
 #include <omp.h>
 #include <stdio.h>
-#include <tr1/memory>
-#include "Magick++.h"
-#include "Cache.h"
+#include <memory>
+#include "CacheMemory.h"
 #include "Exceptions.h"
-
-using namespace std;
+#include "MagickUtilities.h"
 
 namespace openshot
 {
@@ -55,7 +59,7 @@ namespace openshot
 	 * r.Open(); // Open the reader
 	 *
 	 * // Get frame number 1 from the video
-	 * tr1::shared_ptr<Frame> f = r.GetFrame(1);
+	 * std::shared_ptr<Frame> f = r.GetFrame(1);
 	 *
 	 * // Now that we have an openshot::Frame object, lets have some fun!
 	 * f->Display(); // Display the frame on the screen
@@ -67,45 +71,51 @@ namespace openshot
 	class ImageReader : public ReaderBase
 	{
 	private:
-		string path;
-		tr1::shared_ptr<Magick::Image> image;
+		std::string path;
+		std::shared_ptr<Magick::Image> image;
 		bool is_open;
 
 	public:
 
 		/// Constructor for ImageReader.  This automatically opens the media file and loads
 		/// frame 1, or it throws one of the following exceptions.
-		ImageReader(string path) throw(InvalidFile);
+		ImageReader(std::string path);
+
+		/// Constructor for ImageReader.  This only opens the media file to inspect its properties
+		/// if inspect_reader=true. When not inspecting the media file, it's much faster, and useful
+		/// when you are inflating the object using JSON after instantiating it.
+		ImageReader(std::string path, bool inspect_reader);
 
 		/// Close File
 		void Close();
 
 		/// Get the cache object used by this reader (always returns NULL for this object)
-		Cache* GetCache() { return NULL; };
+		CacheMemory* GetCache() { return NULL; };
 
 		/// Get an openshot::Frame object for a specific frame number of this reader.  All numbers
 		/// return the same Frame, since they all share the same image data.
 		///
 		/// @returns The requested frame (containing the image)
 		/// @param requested_frame The frame number that is requested.
-		tr1::shared_ptr<Frame> GetFrame(long int requested_frame) throw(ReaderClosed);
+		std::shared_ptr<Frame> GetFrame(int64_t requested_frame);
 
 		/// Determine if reader is open or closed
 		bool IsOpen() { return is_open; };
 
 		/// Return the type name of the class
-		string Name() { return "ImageReader"; };
+		std::string Name() { return "ImageReader"; };
 
 		/// Get and Set JSON methods
-		string Json(); ///< Generate JSON string of this object
-		void SetJson(string value) throw(InvalidJSON); ///< Load JSON string into this object
+		std::string Json(); ///< Generate JSON string of this object
+		void SetJson(std::string value); ///< Load JSON string into this object
 		Json::Value JsonValue(); ///< Generate Json::JsonValue for this object
-		void SetJsonValue(Json::Value root) throw(InvalidFile); ///< Load Json::JsonValue into this object
+		void SetJsonValue(Json::Value root); ///< Load Json::JsonValue into this object
 
 		/// Open File - which is called by the constructor automatically
-		void Open() throw(InvalidFile);
+		void Open();
 	};
 
 }
 
-#endif
+#endif //USE_IMAGEMAGICK
+#endif //OPENSHOT_IMAGE_READER_H
