@@ -3,9 +3,12 @@
  * @brief Header file for Timeline class
  * @author Jonathan Thomas <jonathan@openshot.org>
  *
- * @section LICENSE
+ * @ref License
+ */
+
+/* LICENSE
  *
- * Copyright (c) 2008-2014 OpenShot Studios, LLC
+ * Copyright (c) 2008-2019 OpenShot Studios, LLC
  * <http://www.openshotstudios.com/>. This file is part of
  * OpenShot Library (libopenshot), an open-source project dedicated to
  * delivering high quality video editing and animation solutions to the
@@ -29,7 +32,8 @@
 #define OPENSHOT_TIMELINE_H
 
 #include <list>
-#include <tr1/memory>
+#include <memory>
+#include <set>
 #include <QtGui/QImage>
 #include <QtGui/QPainter>
 #include "CacheBase.h"
@@ -48,9 +52,7 @@
 #include "KeyFrame.h"
 #include "OpenMPUtilities.h"
 #include "ReaderBase.h"
-
-using namespace std;
-using namespace openshot;
+#include "Settings.h"
 
 namespace openshot {
 
@@ -99,6 +101,7 @@ namespace openshot {
 	 *            Fraction(25,1), // framerate
 	 *            44100, // sample rate
 	 *            2 // channels
+	 *            ChannelLayout::LAYOUT_STEREO,
 	 *            );
 	 *
 	 * // Create some clips
@@ -133,7 +136,7 @@ namespace openshot {
 	 * t.Open();
 	 *
 	 * // Get frame number 1 from the timeline (This will generate a new frame, made up from the previous clips and settings)
-	 * tr1::shared_ptr<Frame> f = t.GetFrame(1);
+	 * std::shared_ptr<Frame> f = t.GetFrame(1);
 	 *
 	 * // Now that we have an openshot::Frame object, lets have some fun!
 	 * f->Display(); // Display the frame on the screen
@@ -146,26 +149,28 @@ namespace openshot {
 	private:
 		bool is_open; ///<Is Timeline Open?
 		bool auto_map_clips; ///< Auto map framerates and sample rates to all clips
-		list<Clip*> clips; ///<List of clips on this timeline
-		list<Clip*> closing_clips; ///<List of clips that need to be closed
-		map<Clip*, Clip*> open_clips; ///<List of 'opened' clips on this timeline
-		list<EffectBase*> effects; ///<List of clips on this timeline
+		std::list<Clip*> clips; ///<List of clips on this timeline
+		std::list<Clip*> closing_clips; ///<List of clips that need to be closed
+		std::map<Clip*, Clip*> open_clips; ///<List of 'opened' clips on this timeline
+		std::list<EffectBase*> effects; ///<List of clips on this timeline
 		CacheBase *final_cache; ///<Final cache of timeline frames
+		std::set<FrameMapper*> allocated_frame_mappers; ///< all the frame mappers we allocated and must free
+		bool managed_cache; ///< Does this timeline instance manage the cache object
 
 		/// Process a new layer of video or audio
-		void add_layer(tr1::shared_ptr<Frame> new_frame, Clip* source_clip, long int clip_frame_number, long int timeline_frame_number, bool is_top_clip);
+		void add_layer(std::shared_ptr<Frame> new_frame, Clip* source_clip, int64_t clip_frame_number, int64_t timeline_frame_number, bool is_top_clip, float max_volume);
 
 		/// Apply a FrameMapper to a clip which matches the settings of this timeline
 		void apply_mapper_to_clip(Clip* clip);
 
 		/// Apply JSON Diffs to various objects contained in this timeline
-		void apply_json_to_clips(Json::Value change) throw(InvalidJSONKey); ///<Apply JSON diff to clips
-		void apply_json_to_effects(Json::Value change) throw(InvalidJSONKey); ///< Apply JSON diff to effects
-		void apply_json_to_effects(Json::Value change, EffectBase* existing_effect) throw(InvalidJSONKey); ///<Apply JSON diff to a specific effect
-		void apply_json_to_timeline(Json::Value change) throw(InvalidJSONKey); ///<Apply JSON diff to timeline properties
+		void apply_json_to_clips(Json::Value change); ///<Apply JSON diff to clips
+		void apply_json_to_effects(Json::Value change); ///< Apply JSON diff to effects
+		void apply_json_to_effects(Json::Value change, EffectBase* existing_effect); ///<Apply JSON diff to a specific effect
+		void apply_json_to_timeline(Json::Value change); ///<Apply JSON diff to timeline properties
 
 		/// Calculate time of a frame number, based on a framerate
-		double calculate_time(long int number, Fraction rate);
+		double calculate_time(int64_t number, Fraction rate);
 
 		/// Find intersecting (or non-intersecting) openshot::Clip objects
 		///
@@ -173,13 +178,13 @@ namespace openshot {
 		/// @param requested_frame The frame number that is requested.
 		/// @param number_of_frames The number of frames to check
 		/// @param include Include or Exclude intersecting clips
-		vector<Clip*> find_intersecting_clips(long int requested_frame, int number_of_frames, bool include);
+		std::vector<Clip*> find_intersecting_clips(int64_t requested_frame, int number_of_frames, bool include);
 
 		/// Get or generate a blank frame
-		tr1::shared_ptr<Frame> GetOrCreateFrame(Clip* clip, long int number);
+		std::shared_ptr<Frame> GetOrCreateFrame(Clip* clip, int64_t number);
 
 		/// Apply effects to the source frame (if any)
-		tr1::shared_ptr<Frame> apply_effects(tr1::shared_ptr<Frame> frame, long int timeline_frame_number, int layer);
+		std::shared_ptr<Frame> apply_effects(std::shared_ptr<Frame> frame, int64_t timeline_frame_number, int layer);
 
 		/// Compare 2 floating point numbers for equality
 		bool isEqual(double a, double b);
@@ -204,9 +209,11 @@ namespace openshot {
 		/// @param channel_layout The channel layout (i.e. mono, stereo, 3 point surround, etc...)
 		Timeline(int width, int height, Fraction fps, int sample_rate, int channels, ChannelLayout channel_layout);
 
+        virtual ~Timeline();
+
 		/// @brief Add an openshot::Clip to the timeline
 		/// @param clip Add an openshot::Clip to the timeline. A clip can contain any type of Reader.
-		void AddClip(Clip* clip) throw(ReaderClosed);
+		void AddClip(Clip* clip);
 
 		/// @brief Add an effect to the timeline
 		/// @param effect Add an effect to the timeline. An effect can modify the audio or video of an openshot::Frame.
@@ -225,25 +232,26 @@ namespace openshot {
         void ClearAllCache();
 
 		/// Return a list of clips on the timeline
-		list<Clip*> Clips() { return clips; };
+		std::list<Clip*> Clips() { return clips; };
 
 		/// Close the timeline reader (and any resources it was consuming)
 		void Close();
 
 		/// Return the list of effects on the timeline
-		list<EffectBase*> Effects() { return effects; };
+		std::list<EffectBase*> Effects() { return effects; };
 
 		/// Get the cache object used by this reader
 		CacheBase* GetCache() { return final_cache; };
 
-		/// Get the cache object used by this reader
+		/// Set the cache object used by this reader. You must now manage the lifecycle
+		/// of this cache object though (Timeline will not delete it for you).
 		void SetCache(CacheBase* new_cache);
 
 		/// Get an openshot::Frame object for a specific frame number of this timeline.
 		///
 		/// @returns The requested frame (containing the image)
 		/// @param requested_frame The frame number that is requested.
-		tr1::shared_ptr<Frame> GetFrame(long int requested_frame) throw(ReaderClosed, OutOfBoundsFrame);
+		std::shared_ptr<Frame> GetFrame(int64_t requested_frame);
 
 		// Curves for the viewport
 		Keyframe viewport_scale; ///<Curve representing the scale of the viewport (0 to 100)
@@ -257,19 +265,23 @@ namespace openshot {
 		bool IsOpen() { return is_open; };
 
 		/// Return the type name of the class
-		string Name() { return "Timeline"; };
+		std::string Name() { return "Timeline"; };
 
 		/// Get and Set JSON methods
-		string Json(); ///< Generate JSON string of this object
-		void SetJson(string value) throw(InvalidJSON); ///< Load JSON string into this object
+		std::string Json(); ///< Generate JSON string of this object
+		void SetJson(std::string value); ///< Load JSON string into this object
 		Json::Value JsonValue(); ///< Generate Json::JsonValue for this object
-		void SetJsonValue(Json::Value root) throw(InvalidFile, ReaderClosed); ///< Load Json::JsonValue into this object
+		void SetJsonValue(Json::Value root); ///< Load Json::JsonValue into this object
+
+		/// Set Max Image Size (used for performance optimization). Convenience function for setting
+		/// Settings::Instance()->MAX_WIDTH and Settings::Instance()->MAX_HEIGHT.
+		void SetMaxSize(int width, int height);
 
 		/// @brief Apply a special formatted JSON object, which represents a change to the timeline (add, update, delete)
 		/// This is primarily designed to keep the timeline (and its child objects... such as clips and effects) in sync
 		/// with another application... such as OpenShot Video Editor (http://www.openshot.org).
 		/// @param value A JSON string containing a key, value, and type of change.
-		void ApplyJsonDiff(string value) throw(InvalidJSON, InvalidJSONKey);
+		void ApplyJsonDiff(std::string value);
 
 		/// Open the reader (and start consuming resources)
 		void Open();
